import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.JComponent;

/**
 *  A simple Java Swing component that draws a circle.
 *
 *  @author Nicholas R. Howe, modified by Sara Sheehan
 *  @version February 3, 2016
 */
public class JCircle extends JComponent {
	
    /** For serializing the class (ignore for now) */
	private static final long serialVersionUID = 1L;
	
	/** The diameter of the circle */
    private int diameter;

    /**
     *  Creates a JCircle of specified size
     *  @param r Specifies the radius of the circle
     */
    public JCircle(int r) {
    		super();  // call JComponent constructor
    		this.diameter = 2*r;
    }

    /** Accessor for radius */
    public int getRadius() {
    		return this.diameter/2;
    }

    /** Manipulator for radius */
    public void setRadius(int r) {
    		this.diameter = 2*r;
    }

    /**
     *  Draws the circle in the graphics window
     *  @param g The graphics object to draw into
     */
    public void paintComponent(Graphics g) {
    		g.fillOval(0,0,this.diameter,this.diameter);
    }
    
    /**
     *  The component will look bad if it is sized smaller than this
     *
     *  @returns The minimum dimension
     */
    public Dimension getMinimumSize() {
    		return new Dimension(this.diameter,this.diameter);
    }
    
    /**
     *  The component will look best at this size
     *  @returns The preferred dimension
     */
    public Dimension getPreferredSize() {
    		return new Dimension(this.diameter,this.diameter);
    }
}